<?php

namespace Pinpoint\ProductPersonalisation\Controller\Adminhtml\Pdf;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\View\Result\PageFactory;

/**
 * Class Generate
 * @package Pinpoint\ProductPersonalisation\Controller\Adminhtml\Pdf
 */
class Generate extends Action
{
    /**
     * @var \Magento\Sales\Api\OrderRepositoryInterface
     */
    protected $orderRepository;

    /**
     * @var \Pinpoint\ProductPersonalisation\Model\Pdf\Generation
     */
    protected $pdf;

    /**
     * Generate constructor.
     * @param Context $context
     * @param \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
     * @param \Pinpoint\ProductPersonalisation\Model\Pdf\Generation $pdf
     */
    public function __construct(
        Context $context,
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
        \Pinpoint\ProductPersonalisation\Model\Pdf\Generation $pdf
    ) {
        $this->orderRepository = $orderRepository;
        $this->pdf = $pdf;

        parent::__construct($context);
    }

    /**
     * @return string
     */
     public function execute()
     {
         error_reporting(0);
         if ($orderId = $this->getRequest()->getParam('order_id')) {
             $order = $this->orderRepository->get($orderId);
             $productSku = $this->getRequest()->getParam('sku');
             $itemId = $this->getRequest()->getParam('item_id');
             foreach ($order->getItems() as $item) {
                 if ($item->getId() == $itemId) {
                     $options = $item->getProductOptions()['options'];
                     $attribute = '';

                     if (count($options)) {
                         if ($options[0]['option_type'] === 'drop_down') {
                             $attribute .= '-' . $options[0]['value'];
                         }
                     }

                     try {
                         $pdf = $this->pdf->generateMachinePrint($item);
                         $filename = sprintf(
                             '%s-%s-%s%s.pdf',
                             $item->getSku(),
                             (int)$item->getQtyOrdered(),
                             ltrim($order->getIncrementId(), "0"),
                             preg_replace('/\+?[£]\d+[\d,.]*\s*/m', '', $attribute)
                         );

                         return $pdf->Output($filename, \Mpdf\Output\Destination::DOWNLOAD);
                     } catch (\Exception $ex) {
                         exit('Sorry, a print ready PDF is not available for this order item as it doesnt have a template. <a href="javascript:window.close();">Close Tab</a><br/><br/>' . $ex->getTraceAsString());
                     }
                 }
             }
         }
       }
}
